@@ -1,12 +1,13 @@
+import os
 import re
 import sys
-import os
+
 from .._compat import integer_types, long
 from ..helpers.classes import Reference
 from ..helpers.methods import use_common_filters
-from .base import SQLAdapter
-from ..objects import Table, Field, Expression, Query
+from ..objects import Expression, Field, Query, Table
 from . import adapters, with_connection, with_connection_or_raise
+from .base import SQLAdapter
 
 
 @adapters.register_for("oracle")
@@ -17,7 +18,9 @@ class Oracle(SQLAdapter):
     def _initialize_(self):
         super(Oracle, self)._initialize_()
         self.ruri = self.uri.split("://", 1)[1]
-        self.REGEX_CLOB = re.compile("[^']*('[^']*'[^']*)*\:(?P<clob>(C|B)LOB\('([^']|'')*'\))")
+        self.REGEX_CLOB = re.compile(
+            r"[^']*('[^']*'[^']*)*\:(?P<clob>(C|B)LOB\('([^']|'')*'\))"
+        )
         if "threaded" not in self.driver_args:
             self.driver_args["threaded"] = True
         # set character encoding defaults
@@ -69,7 +72,7 @@ class Oracle(SQLAdapter):
     def lastrowid(self, table):
         sequence_name = table._sequence_name
         self.execute("SELECT %s.currval FROM dual;" % sequence_name)
-        return long(self.cursor.fetchone()[0])
+        return int(self.cursor.fetchone()[0])
 
     def sqlsafe_table(self, tablename, original_tablename=None):
         if original_tablename is not None:
@@ -221,7 +224,7 @@ class Oracle(SQLAdapter):
         return rid
 
     def _regex_select_as_parser(self, colname):
-        return re.compile('\s+"(\S+)"').search(colname)
+        return re.compile(r'\s+"(\S+)"').search(colname)
 
     def parse(self, rows, fields, colnames, blob_decode=True, cacheable=False):
         if len(rows) and len(rows[0]) == len(fields) + 1 and type(rows[0][-1]) == int:
