@@ -111,7 +111,7 @@ Supported DAL URI strings::
     'informix://user:password@server:3050/database'
     'informixu://user:password@server:3050/database' # unicode informix
     'ingres://database'  # or use an ODBC connection string, e.g. 'ingres://dsn=dsn_name'
-    'google:datastore' # for google app engine datastore (uses ndb by default)
+    'firestore' # for google firestore
     'google:sql' # for google app engine with sql (mysql compatible)
     'teradata://DSN=dsn;UID=user;PWD=pass; DATABASE=database' # experimental
     'imap://user:password@server:port' # experimental
@@ -133,16 +133,37 @@ import time
 import traceback
 import urllib
 
-from ._compat import (PY2, copyreg, hashlib_md5, integer_types, iteritems,
-                      long, pickle, pjoin, unquote, with_metaclass)
+from ._compat import (
+    PY2,
+    copyreg,
+    hashlib_md5,
+    integer_types,
+    iteritems,
+    long,
+    pickle,
+    pjoin,
+    unquote,
+    with_metaclass,
+)
 from ._globals import DEFAULT, GLOBAL_LOCKER, THREAD_LOCAL
 from ._load import OrderedDict
 from .adapters.base import BaseAdapter, NullAdapter
 from .default_validators import default_validators
-from .helpers.classes import (BasicStorage, RecordDeleter, RecordUpdater,
-                              Serializable, SQLCallableList, TimingHandler)
-from .helpers.methods import (auto_represent, auto_validators, hide_password,
-                              smart_query, uuidstr)
+from .helpers.classes import (
+    BasicStorage,
+    RecordDeleter,
+    RecordUpdater,
+    Serializable,
+    SQLCallableList,
+    TimingHandler,
+)
+from .helpers.methods import (
+    auto_represent,
+    auto_validators,
+    hide_password,
+    smart_query,
+    uuidstr,
+)
 from .helpers.regex import REGEX_DBNAME, REGEX_PYTHON_KEYWORDS
 from .helpers.rest import RestParser
 from .helpers.serializers import serializers
@@ -161,7 +182,6 @@ TABLE_ARGS = set(
         "sequence_name",
         "fields",
         "common_filter",
-        "polymodel",
         "table_class",
         "on_define",
         "rname",
@@ -169,6 +189,7 @@ TABLE_ARGS = set(
 )
 
 
+# TESTING
 class MetaDAL(type):
     def __call__(cls, *args, **kwargs):
         #: intercept arguments for DAL customisation on call
@@ -361,12 +382,12 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
         thread_key = "%s.%s" % (socket.gethostname(), threading.current_thread())
         instances = enumerate(instances)
         keys = ["%s.%i" % (thread_key, i) for (i, db) in instances]
-        for (i, db) in instances:
+        for i, db in instances:
             if not db._adapter.support_distributed_transaction():
                 raise SyntaxError(
                     "distributed transaction not suported by %s" % db._dbname
                 )
-        for (i, db) in instances:
+        for i, db in instances:
             db._adapter.distributed_transaction_begin(keys[i])
 
     @staticmethod
@@ -376,20 +397,20 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
         instances = enumerate(instances)
         thread_key = "%s.%s" % (socket.gethostname(), threading.current_thread())
         keys = ["%s.%i" % (thread_key, i) for (i, db) in instances]
-        for (i, db) in instances:
+        for i, db in instances:
             if not db._adapter.support_distributed_transaction():
                 raise SyntaxError(
                     "distributed transaction not suported by %s" % db._dbanme
                 )
         try:
-            for (i, db) in instances:
+            for i, db in instances:
                 db._adapter.prepare(keys[i])
         except:
-            for (i, db) in instances:
+            for i, db in instances:
                 db._adapter.rollback_prepared(keys[i])
             raise RuntimeError("failure to commit distributed transaction")
         else:
-            for (i, db) in instances:
+            for i, db in instances:
                 db._adapter.commit_prepared(keys[i])
         return
 
@@ -419,7 +440,6 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
         entity_quoting=True,
         table_hash=None,
     ):
-
         if uri == "<zombie>" and db_uid is not None:
             return
         super(DAL, self).__init__()
@@ -461,6 +481,7 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
         self._decode_credentials = decode_credentials
         self._attempts = attempts
         self._ignore_field_case = ignore_field_case
+        self._dbname = None
 
         if not str(attempts).isdigit() or attempts < 0:
             attempts = 5
@@ -597,7 +618,7 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
                     self.define_table(
                         name,
                         *[item[1] for item in mf],
-                        **dict(migrate=migrate, fake_migrate=fake_migrate)
+                        **dict(migrate=migrate, fake_migrate=fake_migrate),
                     )
                 finally:
                     self._adapter.migrator.file_close(tfile)
@@ -644,7 +665,7 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
                 raise SyntaxError("table already defined: %s" % tablename)
         elif (
             tablename.startswith("_")
-            or tablename in dir(self)
+            or hasattr(self, tablename)
             or REGEX_PYTHON_KEYWORDS.match(tablename)
         ):
             raise SyntaxError("invalid table name: %s" % tablename)
@@ -681,22 +702,22 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
                 field.represent = auto_represent(field)
 
         migrate = self._migrate_enabled and kwargs_get("migrate", self._migrate)
-        if (
-            migrate
-            and self._uri not in (None, "None")
-            or self._adapter.dbengine == "google:datastore"
-        ):
+        if self._adapter.dbengine in ("firestore"):
+            migrate = False
+        elif self._uri in (None, "None"):
+            migrate = False
+        else:
+            migrate = self._migrate_enabled and kwargs_get("migrate", self._migrate)
+        if migrate:
             fake_migrate = self._fake_migrate_all or kwargs_get(
                 "fake_migrate", self._fake_migrate
             )
-            polymodel = kwargs_get("polymodel", None)
             try:
                 GLOBAL_LOCKER.acquire()
                 self._adapter.create_table(
                     table,
                     migrate=migrate,
                     fake_migrate=fake_migrate,
-                    polymodel=polymodel,
                 )
             finally:
                 GLOBAL_LOCKER.release()
@@ -736,7 +757,7 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
                         "lazy_tables",
                     ]
                 ]
-            )
+            ),
         )
         for table in self:
             db_as_dict["tables"].append(table.as_dict(flat=flat, sanitize=sanitize))
@@ -962,7 +983,7 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
         return self.representers[name](*args, **kwargs)
 
     def export_to_csv_file(self, ofile, *args, **kwargs):
-        step = long(kwargs.get("max_fetch_rows", 500))
+        step = int(kwargs.get("max_fetch_rows", 500))
         write_colnames = kwargs["write_colnames"] = kwargs.get("write_colnames", True)
         for table in self.tables:
             ofile.write("TABLE %s\r\n" % table)
@@ -986,7 +1007,7 @@ class DAL(with_metaclass(MetaDAL, Serializable, BasicStorage)):
         map_tablenames=None,
         ignore_missing_tables=False,
         *args,
-        **kwargs
+        **kwargs,
     ):
         # if id_map is None: id_map={}
         id_offset = {}  # only used if id_map is None
