@@ -31,7 +31,6 @@ if b"\0"[0] == 0:  # Python 3 semantics
     def _compat_bytes_to_byte_vals(byt):
         return byt
 
-
 else:
 
     def _compat_bytes_to_byte_vals(byt):
@@ -55,11 +54,11 @@ def _compat_to_bytes(intval, length, endianess):
     assert isinstance(intval, _compat_int_types)
     assert endianess == "big"
     if length == 4:
-        if intval < 0 or intval >= 2 ** 32:
+        if intval < 0 or intval >= 2**32:
             raise struct.error("integer out of range for 'I' format code")
         return struct.pack(b"!I", intval)
     elif length == 16:
-        if intval < 0 or intval >= 2 ** 128:
+        if intval < 0 or intval >= 2**128:
             raise struct.error("integer out of range for 'QQ' format code")
         return struct.pack(b"!QQ", intval >> 64, intval & 0xFFFFFFFFFFFFFFFF)
     else:
@@ -71,7 +70,6 @@ if hasattr(int, "bit_length"):
     def _compat_bit_length(i):
         return i.bit_length()
 
-
 else:
 
     def _compat_bit_length(i):
@@ -510,7 +508,6 @@ def get_mixed_type_key(obj):
 
 
 class _IPAddressBase(_TotalOrderingMixin):
-
     """The mother class."""
 
     __slots__ = ()
@@ -667,7 +664,6 @@ class _IPAddressBase(_TotalOrderingMixin):
 
 
 class _BaseAddress(_IPAddressBase):
-
     """A generic IP object.
 
     This IP class contains the version independent methods which are
@@ -725,7 +721,6 @@ class _BaseAddress(_IPAddressBase):
 
 
 class _BaseNetwork(_IPAddressBase):
-
     """A generic IP network object.
 
     This IP class contains the version independent methods which are
@@ -938,8 +933,7 @@ class _BaseNetwork(_IPAddressBase):
         else:
             # If we got here, there's a bug somewhere.
             raise AssertionError(
-                "Error performing exclusion: "
-                "s1: %s s2: %s other: %s" % (s1, s2, other)
+                "Error performing exclusion: s1: %s s2: %s other: %s" % (s1, s2, other)
             )
 
     def compare_networks(self, other):
@@ -1214,7 +1208,6 @@ class _BaseNetwork(_IPAddressBase):
 
 
 class _BaseV4(object):
-
     """Base IPv4 object.
 
     The following methods are used by IPv4 objects in both single IP
@@ -1225,7 +1218,7 @@ class _BaseV4(object):
     __slots__ = ()
     _version = 4
     # Equivalent to 255.255.255.255 or 32 bits of 1's.
-    _ALL_ONES = (2 ** IPV4LENGTH) - 1
+    _ALL_ONES = (2**IPV4LENGTH) - 1
     _DECIMAL_DIGITS = frozenset("0123456789")
 
     # the valid octets for host and netmasks. only useful for IPv4.
@@ -1382,13 +1375,11 @@ class _BaseV4(object):
 
 
 class IPv4Address(_BaseV4, _BaseAddress):
-
     """Represent and manipulate single IPv4 Addresses."""
 
     __slots__ = ("_ip", "__weakref__")
 
     def __init__(self, address):
-
         """
         Args:
             address: A string or integer representing the IP
@@ -1575,7 +1566,6 @@ class IPv4Interface(IPv4Address):
 
 
 class IPv4Network(_BaseV4, _BaseNetwork):
-
     """This class represents and manipulates 32-bit IPv4 network + addresses..
 
     Attributes: [examples for IPv4Network('192.0.2.0/27')]
@@ -1591,7 +1581,6 @@ class IPv4Network(_BaseV4, _BaseNetwork):
     _address_class = IPv4Address
 
     def __init__(self, address, strict=True):
-
         """Instantiate a new IPv4 network object.
 
         Args:
@@ -1695,7 +1684,6 @@ class IPv4Network(_BaseV4, _BaseNetwork):
 
 
 class _IPv4Constants(object):
-
     _linklocal_network = IPv4Network("169.254.0.0/16")
 
     _loopback_network = IPv4Network("127.0.0.0/8")
@@ -1730,7 +1718,6 @@ IPv4Address._constants = _IPv4Constants
 
 
 class _BaseV6(object):
-
     """Base IPv6 object.
 
     The following methods are used by IPv6 objects in both single IP
@@ -1740,7 +1727,7 @@ class _BaseV6(object):
 
     __slots__ = ()
     _version = 6
-    _ALL_ONES = (2 ** IPV6LENGTH) - 1
+    _ALL_ONES = (2**IPV6LENGTH) - 1
     _HEXTET_COUNT = 8
     _HEX_DIGITS = frozenset("0123456789ABCDEFabcdef")
     _max_prefixlen = IPV6LENGTH
@@ -2013,7 +2000,6 @@ class _BaseV6(object):
 
 
 class IPv6Address(_BaseV6, _BaseAddress):
-
     """Represent and manipulate single IPv6 Addresses."""
 
     __slots__ = ("_ip", "__weakref__")
@@ -2276,7 +2262,6 @@ class IPv6Interface(IPv6Address):
 
 
 class IPv6Network(_BaseV6, _BaseNetwork):
-
     """This class represents and manipulates 128-bit IPv6 networks.
 
     Attributes: [examples for IPv6('2001:db8::1000/124')]
@@ -2401,7 +2386,6 @@ class IPv6Network(_BaseV6, _BaseNetwork):
 
 
 class _IPv6Constants(object):
-
     _linklocal_network = IPv6Network("fe80::/10")
 
     _multicast_network = IPv6Network("ff00::/8")
