@@ -2,15 +2,18 @@
 
 DRIVERS = {}
 
-from ._gae import gae
+try:
+    from google.cloud import firestore
+    from google.cloud.firestore_v1.base_query import FieldFilter
 
-if gae is not None:
-    DRIVERS["google"] = gae
+    DRIVERS["firestore"] = firestore
     psycopg2_adapt = None
     cx_Oracle = None
     pyodbc = None
     couchdb = None
     is_jdbc = False
+except ImportError:
+    pass
 
 try:
     from pysqlite2 import dbapi2 as sqlite2
@@ -145,8 +148,8 @@ except ImportError:
     pass
 
 try:
-    from com.ziclix.python.sql import zxJDBC
     import java.sql
+    from com.ziclix.python.sql import zxJDBC
 
     # Try sqlite jdbc driver from http://www.zentus.com/sqlitejdbc/
     from org.sqlite import JDBC  # required by java.sql; ensure we have it
