@@ -6,8 +6,17 @@ import threading
 import time
 import traceback
 
-from .._compat import (PY2, copyreg, exists, implements_bool, iteritems,
-                       iterkeys, itervalues, long, to_bytes)
+from .._compat import (
+    PY2,
+    copyreg,
+    exists,
+    implements_bool,
+    iteritems,
+    iterkeys,
+    itervalues,
+    long,
+    to_bytes,
+)
 from .._globals import THREAD_LOCAL
 from .serializers import serializers
 
@@ -180,19 +189,19 @@ class Serializable(object):
         return serializers.yaml(self.as_dict(flat=True, sanitize=sanitize))
 
 
-class Reference(long):
+class Reference(int):
     def __allocate(self):
         if not self._record:
-            self._record = self._table[long(self)]
+            self._record = self._table[int(self)]
         if not self._record:
             raise RuntimeError(
                 "Using a recursive select but encountered a broken "
-                + "reference: %s %d" % (self._table, long(self))
+                + "reference: %s %d" % (self._table, int(self))
             )
 
     def __getattr__(self, key, default=None):
         if key == "id":
-            return long(self)
+            return int(self)
         if key in self._table:
             self.__allocate()
         if self._record:
@@ -213,7 +222,7 @@ class Reference(long):
 
     def __getitem__(self, key):
         if key == "id":
-            return long(self)
+            return int(self)
         self.__allocate()
         return self._record.get(key, None)
 
@@ -228,9 +237,9 @@ def Reference_unpickler(data):
 
 def Reference_pickler(data):
     try:
-        marshal_dump = marshal.dumps(long(data))
+        marshal_dump = marshal.dumps(int(data))
     except AttributeError:
-        marshal_dump = "i%s" % struct.pack("<i", long(data))
+        marshal_dump = "i%s" % struct.pack("<i", int(data))
     return (Reference_unpickler, (marshal_dump,))
 
 
@@ -475,7 +484,6 @@ class TimingHandler(ExecutionHandler):
 
 
 class DatabaseStoredFile:
-
     web2py_filesystems = set()
 
     def escape(self, obj):
@@ -488,8 +496,11 @@ class DatabaseStoredFile:
                 raise NotImplementedError(
                     "DatabaseStoredFile only supported by mysql, potresql, sqlite"
                 )
-            blobType = "BYTEA" if db._adapter.dbengine == "postgres" else "BLOB" 
-            sql = "CREATE TABLE IF NOT EXISTS web2py_filesystem (path VARCHAR(255), content %(blobType)s, PRIMARY KEY(path));" % {"blobType": blobType}
+            blobType = "BYTEA" if db._adapter.dbengine == "postgres" else "BLOB"
+            sql = (
+                "CREATE TABLE IF NOT EXISTS web2py_filesystem (path VARCHAR(255), content %(blobType)s, PRIMARY KEY(path));"
+                % {"blobType": blobType}
+            )
             if db._adapter.dbengine == "mysql":
                 sql = sql[:-1] + " ENGINE=InnoDB;"
             db.executesql(sql)
@@ -547,8 +558,11 @@ class DatabaseStoredFile:
             self.db.executesql(
                 "DELETE FROM web2py_filesystem WHERE path='%s'" % self.filename
             )
-            placeholder = "?" if self.db._adapter.dbengine == "sqlite" else "%s" 
-            query = "INSERT INTO web2py_filesystem(path,content) VALUES (%(placeholder)s, %(placeholder)s)" % {"placeholder": placeholder}
+            placeholder = "?" if self.db._adapter.dbengine == "sqlite" else "%s"
+            query = (
+                "INSERT INTO web2py_filesystem(path,content) VALUES (%(placeholder)s, %(placeholder)s)"
+                % {"placeholder": placeholder}
+            )
             args = (self.filename, self.data)
             self.db.executesql(query, args)
             self.db.commit()
