@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 """
-    pydal.utils
-    -----------
+pydal.utils
+-----------
 
-    Provides some utilities for pydal.
+Provides some utilities for pydal.
 
-    :copyright: (c) 2017 by Giovanni Barillari and contributors
-    :license: BSD, see LICENSE for more details.
+:copyright: (c) 2017 by Giovanni Barillari and contributors
+:license: BSD, see LICENSE for more details.
 """
 
+import datetime
 import re
 import warnings
 
@@ -20,6 +21,11 @@ class RemovedInNextVersionWarning(DeprecationWarning):
 warnings.simplefilter("always", RemovedInNextVersionWarning)
 
 
+def utcnow():
+    """returns the current time in utc"""
+    return datetime.datetime.now(datetime.timezone.utc).replace(tzinfo=None)
+
+
 def warn_of_deprecation(old_name, new_name, prefix=None, stack=2):
     msg = "%(old)s is deprecated, use %(new)s instead."
     if prefix:
