@@ -1,17 +1,22 @@
-﻿#!/usr/bin/env python
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-"""Unit tests for http.py """
+"""Unit tests for validators.py"""
 
-import unittest
 import datetime
 import decimal
 import re
+import unittest
+import warnings
+
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore", DeprecationWarning)
+    import cgi
 
 from pydal import DAL, Field
-from pydal.validators import *
 from pydal._compat import PY2, to_bytes
-from pydal.validators import options_sorter, Validator, UTC
+from pydal.validators import *
+from pydal.validators import UTC, Validator, options_sorter
 
 
 class TestValidators(unittest.TestCase):
@@ -21,12 +26,11 @@ class TestValidators(unittest.TestCase):
         return getattr(self, "assertRegex")(*args, **kwargs)
 
     def test_MISC(self):
-        """ Test miscelaneous utility functions and some general behavior guarantees """
+        """Test miscelaneous utility functions and some general behavior guarantees"""
 
         self.assertEqual(options_sorter(("a", "a"), ("a", "a")), -1)
         self.assertEqual(options_sorter(("A", "A"), ("a", "a")), -1)
         self.assertEqual(options_sorter(("b", "b"), ("a", "a")), 1)
-        self.assertRaises(NotImplementedError, Validator(), 1)
         utc = UTC()
         dt = datetime.datetime.now()
         self.assertEqual(utc.utcoffset(dt), UTC.ZERO)
@@ -56,18 +60,18 @@ class TestValidators(unittest.TestCase):
         self.assertEqual(rtn, ("hellas", "Invalid expression"))
         rtn = IS_MATCH("^.hell$", strict=True)("shell")
         self.assertEqual(rtn, ("shell", None))
-        rtn = IS_MATCH(u"hell", is_unicode=True)("àòè")
+        rtn = IS_MATCH("hell", is_unicode=True)("àòè")
         if PY2:
             self.assertEqual(rtn, ("\xc3\xa0\xc3\xb2\xc3\xa8", "Invalid expression"))
         else:
             self.assertEqual(rtn, ("àòè", "Invalid expression"))
-        rtn = IS_MATCH(u"hell", is_unicode=True)(u"hell")
-        self.assertEqual(rtn, (u"hell", None))
-        rtn = IS_MATCH("hell", is_unicode=True)(u"hell")
-        self.assertEqual(rtn, (u"hell", None))
+        rtn = IS_MATCH("hell", is_unicode=True)("hell")
+        self.assertEqual(rtn, ("hell", None))
+        rtn = IS_MATCH("hell", is_unicode=True)("hell")
+        self.assertEqual(rtn, ("hell", None))
         # regr test for #1044
-        rtn = IS_MATCH("hello")(u"\xff")
-        self.assertEqual(rtn, (u"\xff", "Invalid expression"))
+        rtn = IS_MATCH("hello")("\xff")
+        self.assertEqual(rtn, ("\xff", "Invalid expression"))
 
     def test_IS_EQUAL_TO(self):
         rtn = IS_EQUAL_TO("aaa")("aaa")
@@ -107,7 +111,7 @@ class TestValidators(unittest.TestCase):
         rtn = IS_LENGTH(minsize=1)([1])
         self.assertEqual(rtn, ([1], None))
         # test non utf-8 str
-        cpstr = u"lálá".encode("cp1252")
+        cpstr = "lálá".encode("cp1252")
         rtn = IS_LENGTH(minsize=4)(cpstr)
         self.assertEqual(rtn, (cpstr, None))
         rtn = IS_LENGTH(maxsize=4)(cpstr)
@@ -115,23 +119,22 @@ class TestValidators(unittest.TestCase):
         rtn = IS_LENGTH(minsize=0, maxsize=3)(cpstr)
         self.assertEqual(rtn, (cpstr, "Enter from 0 to 3 characters"))
         # test unicode
-        rtn = IS_LENGTH(2)(u"°2")
+        rtn = IS_LENGTH(2)("°2")
         if PY2:
             self.assertEqual(rtn, ("\xc2\xb02", None))
         else:
-            self.assertEqual(rtn, (u"°2", None))
-        rtn = IS_LENGTH(2)(u"°12")
+            self.assertEqual(rtn, ("°2", None))
+        rtn = IS_LENGTH(2)("°12")
         if PY2:
-            self.assertEqual(rtn, (u"\xb012", "Enter from 0 to 2 characters"))
+            self.assertEqual(rtn, ("\xb012", "Enter from 0 to 2 characters"))
         else:
-            self.assertEqual(rtn, (u"°12", "Enter from 0 to 2 characters"))
+            self.assertEqual(rtn, ("°12", "Enter from 0 to 2 characters"))
         # test automatic str()
         rtn = IS_LENGTH(minsize=1)(1)
         self.assertEqual(rtn, ("1", None))
         rtn = IS_LENGTH(minsize=2)(1)
         self.assertEqual(rtn, (1, "Enter from 2 to 255 characters"))
         # test FieldStorage
-        import cgi
         from io import BytesIO
 
         a = cgi.FieldStorage()
@@ -158,13 +161,13 @@ class TestValidators(unittest.TestCase):
 
     def test_IS_JSON(self):
         rtn = IS_JSON()('{"a": 100}')
-        self.assertEqual(rtn, ({u"a": 100}, None))
+        self.assertEqual(rtn, ({"a": 100}, None))
         rtn = IS_JSON()("spam1234")
         self.assertEqual(rtn, ("spam1234", "Invalid json"))
         rtn = IS_JSON(native_json=True)('{"a": 100}')
         self.assertEqual(rtn, ('{"a": 100}', None))
         rtn = IS_JSON().formatter(None)
-        self.assertEqual(rtn, None)
+        self.assertEqual(rtn, "null")
         rtn = IS_JSON().formatter({"a": 100})
         self.assertEqual(rtn, '{"a": 100}')
         rtn = IS_JSON(native_json=True).formatter({"a": 100})
@@ -210,6 +213,15 @@ class TestValidators(unittest.TestCase):
         rtn = IS_IN_SET(["id2", "id1"], sort=True).options(zero=False)
         self.assertEqual(rtn, [("id1", "id1"), ("id2", "id2")])
 
+        # sets can be lazy
+        theset = []
+        validator = IS_IN_SET(lambda: theset)
+        rtn = validator("max")
+        self.assertEqual(rtn, ("max", "Value not allowed"))
+        theset.append("max")
+        rtn = validator("max")
+        self.assertEqual(rtn, ("max", None))
+
     def test_IS_IN_DB(self):
         db = DAL("sqlite:memory")
         db.define_table("person", Field("name"))
@@ -301,11 +313,13 @@ class TestValidators(unittest.TestCase):
             Field("name"),
         )
         ret = db.category.validate_and_insert(name="seinfeld")
-        self.assertFalse(list(ret.errors))
-        ret = db.category.validate_and_insert(name="characters", parent_id=ret.id)
-        self.assertFalse(list(ret.errors))
-        rtn = IS_IN_DB(db, "category.id", "%(name)s")(ret.id)
-        self.assertEqual(rtn, (ret.id, None))
+        self.assertFalse(ret.get("errors"))
+        ret = db.category.validate_and_insert(
+            name="characters", parent_id=ret.get("id")
+        )
+        self.assertFalse(ret.get("errors"))
+        rtn = IS_IN_DB(db, "category.id", "%(name)s")(ret.get("id"))
+        self.assertEqual(rtn, (ret.get("id"), None))
         # Test _and
         vldtr = IS_IN_DB(
             db,
@@ -333,11 +347,11 @@ class TestValidators(unittest.TestCase):
             "ref_table", Field("name"), Field("person_id", "reference person")
         )
         ret = db.ref_table.validate_and_insert(name="test reference table")
-        self.assertFalse(list(ret.errors))
+        self.assertTrue(not ret.get("errors"))
         ret = db.ref_table.validate_and_insert(
             name="test reference table", person_id=george_id
         )
-        self.assertFalse(list(ret.errors))
+        self.assertTrue(not ret.get("errors"))
         rtn = IS_IN_DB(db, "ref_table.person_id", "%(name)s")(george_id)
         self.assertEqual(rtn, (george_id, None))
         # Test it works with reference table.field and keyed table
@@ -349,14 +363,14 @@ class TestValidators(unittest.TestCase):
         db.define_table(
             "ref_table_field",
             Field("name"),
-            Field("person_name", "reference person_keyed.name"),
+            Field("person_name", "reference person_keyed.name", requires=[]),
         )
         ret = db.ref_table_field.validate_and_insert(name="test reference table.field")
-        self.assertFalse(list(ret.errors))
+        self.assertTrue(not ret.get("errors"))
         ret = db.ref_table_field.validate_and_insert(
             name="test reference table.field", person_name="george"
         )
-        self.assertFalse(list(ret.errors))
+        self.assertTrue(not ret.get("errors"))
         vldtr = IS_IN_DB(db, "ref_table_field.person_name", "%(name)s")
         vldtr.options()
         rtn = vldtr("george")
@@ -367,41 +381,52 @@ class TestValidators(unittest.TestCase):
             Field("name"),
             Field("person_list", "list:reference person"),
         )
+        self.assertEqual(db.list_ref_table.person_list.referenced_table(), db.person)
         ret = db.list_ref_table.validate_and_insert(name="test list:reference table")
-        self.assertFalse(list(ret.errors))
+        self.assertTrue(not ret.get("errors"))
         ret = db.list_ref_table.validate_and_insert(
             name="test list:reference table", person_list=[george_id, costanza_id]
         )
-        self.assertFalse(list(ret.errors))
+        self.assertTrue(not ret.get("errors"))
         vldtr = IS_IN_DB(db, "list_ref_table.person_list")
         vldtr.options()
         rtn = vldtr([george_id, costanza_id])
         self.assertEqual(rtn, ([george_id, costanza_id], None))
-        # Test it works with list:reference table.field and keyed table
-        # db.define_table('list_ref_table_field',
-        #                Field('name'),
-        #                Field('person_list', 'list:reference person_keyed.name'))
-        # ret = db.list_ref_table_field.validate_and_insert(name='test list:reference table.field')
-        # self.assertFalse(list(ret.errors))
-        # ret = db.list_ref_table_field.validate_and_insert(name='test list:reference table.field', person_list=['george','costanza'])
-        # self.assertFalse(list(ret.errors))
-        # vldtr = IS_IN_DB(db, 'list_ref_table_field.person_list')
-        # vldtr.options()
-        # rtn = vldtr(['george','costanza'])
-        # self.assertEqual(rtn, (['george','costanza'], None))
         db.person.drop()
         db.category.drop()
         db.person_keyed.drop()
         db.ref_table.drop()
         db.ref_table_field.drop()
         db.list_ref_table.drop()
-        # db.list_ref_table_field.drop()
+
+    def test_IS_IN_DB_options(self):
+        db = DAL("sqlite:memory")
+        db.define_table("thing", Field("name"))
+        db.thing.insert(name="red")
+        db.thing.insert(name="green")
+        assert IS_IN_DB(db, "thing").options() == [("", ""), ("1", "1"), ("2", "2")]
+        # setting a format for the validator
+        db.thing._format = lambda i: i.name
+        assert IS_IN_DB(db, "thing").options() == [
+            ("", ""),
+            ("1", "red"),
+            ("2", "green"),
+        ]
+        assert IS_IN_DB(db, "thing", zero=None).options() == [
+            ("1", "red"),
+            ("2", "green"),
+        ]
+        assert IS_IN_DB(db, "thing", zero="x").options() == [
+            ("", "x"),
+            ("1", "red"),
+            ("2", "green"),
+        ]
 
     def test_IS_NOT_IN_DB(self):
         db = DAL("sqlite:memory")
         db.define_table("person", Field("name"), Field("nickname"))
         db.person.insert(name="george")
-        db.person.insert(name="costanza", nickname="T Bone")
+        costanza_id = db.person.insert(name="costanza", nickname="T Bone")
         rtn = IS_NOT_IN_DB(db, "person.name", error_message="oops")("george")
         self.assertEqual(rtn, ("george", "oops"))
         rtn = IS_NOT_IN_DB(
@@ -412,14 +437,14 @@ class TestValidators(unittest.TestCase):
         self.assertEqual(rtn, ("  ", "oops"))
         rtn = IS_NOT_IN_DB(db, "person.name")("jerry")
         self.assertEqual(rtn, ("jerry", None))
-        rtn = IS_NOT_IN_DB(db, "person.name")(u"jerry")
+        rtn = IS_NOT_IN_DB(db, "person.name")("jerry")
         self.assertEqual(rtn, ("jerry", None))
-        rtn = IS_NOT_IN_DB(db(db.person.id > 0), "person.name")(u"jerry")
+        rtn = IS_NOT_IN_DB(db(db.person.id > 0), "person.name")("jerry")
         self.assertEqual(rtn, ("jerry", None))
         rtn = IS_NOT_IN_DB(db, db.person, error_message="oops")(1)
         self.assertEqual(rtn, (1, "oops"))
         vldtr = IS_NOT_IN_DB(db, "person.name", error_message="oops")
-        vldtr.set_self_id({"name": "costanza", "nickname": "T Bone"})
+        vldtr.set_self_id(costanza_id)
         rtn = vldtr("george")
         self.assertEqual(rtn, ("george", "oops"))
         rtn = vldtr("costanza")
@@ -651,7 +676,7 @@ class TestValidators(unittest.TestCase):
         rtn = IS_EMAIL(banned=r"^.*\.com(|\..*)$")("abc@example.com")
         self.assertEqual(rtn, ("abc@example.com", "Enter a valid email address"))
         # test for forced
-        rtn = IS_EMAIL(forced="^.*\.edu(|\..*)$")("localguy@localhost")
+        rtn = IS_EMAIL(forced=r"^.*\.edu(|\..*)$")("localguy@localhost")
         self.assertEqual(rtn, ("localguy@localhost", "Enter a valid email address"))
         rtn = IS_EMAIL(forced=r"^.*\.edu(|\..*)$")("localguy@example.edu")
         self.assertEqual(rtn, ("localguy@example.edu", None))
@@ -666,16 +691,18 @@ class TestValidators(unittest.TestCase):
     def test_IS_LIST_OF_EMAILS(self):
         emails = ["localguy@localhost", "_Yosemite.Sam@example.com"]
         rtn = IS_LIST_OF_EMAILS()(",".join(emails))
-        self.assertEqual(rtn, (",".join(emails), None))
+        self.assertEqual(rtn, (emails, None))
         rtn = IS_LIST_OF_EMAILS()(";".join(emails))
-        self.assertEqual(rtn, (";".join(emails), None))
+        self.assertEqual(rtn, (emails, None))
         rtn = IS_LIST_OF_EMAILS()(" ".join(emails))
-        self.assertEqual(rtn, (" ".join(emails), None))
+        self.assertEqual(rtn, (emails, None))
         emails.append("a")
         rtn = IS_LIST_OF_EMAILS()(";".join(emails))
         self.assertEqual(
             rtn, ("localguy@localhost;_Yosemite.Sam@example.com;a", "Invalid emails: a")
         )
+        rtn = IS_LIST_OF_EMAILS()("")
+        self.assertEqual(rtn, ([], None))
         rtn = IS_LIST_OF_EMAILS().formatter(["test@example.com", "dude@example.com"])
         self.assertEqual(rtn, "test@example.com, dude@example.com")
 
@@ -755,7 +782,6 @@ class TestValidators(unittest.TestCase):
         # https://github.com/web2py/web2py/issues/1094
 
         class DummyTimezone(datetime.tzinfo):
-
             ONE = datetime.timedelta(hours=1)
 
             def utcoffset(self, dt):
@@ -866,6 +892,58 @@ class TestValidators(unittest.TestCase):
         rtn = v("clearly not a date")
         self.assertEqual(rtn, ("clearly not a date", "oops"))
 
+    def test_IS_LIST_OF_STRINRGS(self):
+        rtn = IS_LIST_OF_STRINGS()("abc")
+        self.assertEqual(rtn, (["abc"], None))
+        rtn = IS_LIST_OF_STRINGS()(["a", "b", "c"])
+        self.assertEqual(rtn, (["a", "b", "c"], None))
+        rtn = IS_LIST_OF_STRINGS()("a,b,c")
+        self.assertEqual(rtn, (["a", "b", "c"], None))
+        rtn = IS_LIST_OF_STRINGS()("a,b;c")
+        self.assertEqual(rtn, (["a", "b", "c"], None))
+        rtn = IS_LIST_OF_STRINGS()('a,"hello world"; c')
+        self.assertEqual(rtn, (["a", "hello world", "c"], None))
+        rtn = IS_LIST_OF_STRINGS()('a,"hello\\" world"; c')
+        self.assertEqual(rtn, (["a", 'hello" world', "c"], None))
+        rtn = IS_LIST_OF_STRINGS().formatter(["a", 'hello" world', "c"])
+        self.assertEqual(rtn, 'a, "hello\\" world", c')
+
+    def test_IS_LIST_OF_INTS(self):
+        # can validate a single number
+        rtn = IS_LIST_OF_INTS()(1)
+        self.assertEqual(rtn, ([1], None))
+        # can validate lists
+        rtn = IS_LIST_OF_INTS()([1])
+        self.assertEqual(rtn, ([1], None))
+        rtn = IS_LIST_OF_INTS()([1, 2, 3])
+        self.assertEqual(rtn, ([1, 2, 3], None))
+        # can validate numbers as strings
+        rtn = IS_LIST_OF_INTS()("1")
+        self.assertEqual(rtn, ([1], None))
+        # can validate json lists
+        rtn = IS_LIST_OF_INTS()("[1, 2, 3]")
+        self.assertEqual(rtn, ([1, 2, 3], None))
+        rtn = IS_LIST_OF_INTS()('["1", "2", "3"]')
+        self.assertEqual(rtn, ([1, 2, 3], None))
+        # can validate comma separated of semicolon separated numbers
+        rtn = IS_LIST_OF_INTS()("1, 2, 3")
+        self.assertEqual(rtn, ([1, 2, 3], None))
+        rtn = IS_LIST_OF_INTS()("1, 2; 3")
+        self.assertEqual(rtn, ([1, 2, 3], None))
+        # can validate comma separted quoted numbers
+        rtn = IS_LIST_OF_INTS()('1, "2", 3')
+        self.assertEqual(rtn, ([1, 2, 3], None))
+        # check invalid values
+        rtn = IS_LIST_OF_INTS()("abc")
+        self.assertEqual(rtn, ("abc", "Enter a list of integers"))
+        rtn = IS_LIST_OF_INTS()("1, abc, 3")
+        self.assertEqual(rtn, ("1, abc, 3", "Enter a list of integers"))
+        rtn = IS_LIST_OF_INTS()([1, "abc", 3])
+        self.assertEqual(rtn, ([1, "abc", 3], "Enter a list of integers"))
+        # check formatting
+        rtn = IS_LIST_OF_INTS().formatter([1, 2, 3])
+        self.assertEqual(rtn, "1, 2, 3")
+
     def test_IS_LIST_OF(self):
         values = [0, 1, 2, 3, 4]
         rtn = IS_LIST_OF(IS_INT_IN_RANGE(0, 10))(values)
@@ -958,14 +1036,14 @@ class TestValidators(unittest.TestCase):
         self.assertEqual(rtn, "12/14/1834")
 
     class CustomValidator(Validator):
-        """ Custom Validator not overloading .validate() """
+        """Custom Validator not overloading .validate()"""
 
         def __call__(self, value):
             return (value, None) if value else (value, "invalid!")
 
     @staticmethod
     def custom_validator_func(value):
-        """ Validation function instead of Validator subclass """
+        """Validation function instead of Validator subclass"""
         return (value, None) if value else (value, "invalid!")
 
     def test_IS_EMPTY_OR(self):
@@ -1128,8 +1206,8 @@ class TestValidators(unittest.TestCase):
     def test_IS_IMAGE(self):
         class DummyImageFile(object):
             def __init__(self, filename, ext, width, height):
-                from io import BytesIO
                 import struct
+                from io import BytesIO
 
                 self.filename = filename + "." + ext
                 self.file = BytesIO()
@@ -1141,7 +1219,7 @@ class TestValidators(unittest.TestCase):
                     self.file.write(b"GIF87a")
                     self.file.write(struct.pack("<HHB", width, height, 0))
                 elif ext in ("jpg", "jpeg"):
-                    self.file.write(b"\xFF\xD8")
+                    self.file.write(b"\xff\xd8")
                     self.file.write(struct.pack("!BBH", 0xFF, 0xC0, 5))
                     self.file.write(struct.pack("!xHH", height, width))
                 elif ext == "png":
@@ -1196,7 +1274,6 @@ class TestValidators(unittest.TestCase):
         self.assertEqual(rtn, (img, "oops"))
 
     def test_IS_FILE(self):
-        import cgi
         from io import BytesIO
 
         def gen_fake(filename):
@@ -1262,7 +1339,6 @@ this is the content of the fake file
         self.assertEqual(rtn, ("example.pdf", "Enter valid filename"))
 
     def test_IS_UPLOAD_FILENAME(self):
-        import cgi
         from io import BytesIO
 
         def gen_fake(filename):
@@ -1463,3 +1539,13 @@ this is the content of the fake file
         self.assertEqual(rtn, ("2001::8ffa:fe22:b3af", None))
         rtn = IS_IPADDRESS(subnets="invalidsubnet")("2001::8ffa:fe22:b3af")
         self.assertEqual(rtn, ("2001::8ffa:fe22:b3af", "invalid subnet provided"))
+
+    def test_IS_SAFE(self):
+        rtn = IS_SAFE()("<div>test</div>")
+        ("<div></div>", None)
+
+        rtn = IS_SAFE()("<div><script>xxx</script></div>")
+        ("<div><script>xxx</script></div>", "Unsafe Content")
+
+        rtn = IS_SAFE(mode="sanitize")("<div><script>xxx</script></div>")
+        ("<div>xxx</div>", "Unsafe Content")
